@@ -27,6 +27,8 @@ class Position(StrEnum):
     HALF_FORWARD_FLANK_RIGHT = "HFFR"
     FRONT_POCKET_LEFT = "FPL"
     FRONT_POCKET_RIGHT = "FPR"
+    WING_RIGHT = "WR"
+    WING_LEFT = "WL"
 
 
 _POSITIONS = {str(x): x for x in Position}
