@@ -790,7 +790,7 @@ def _create_teams(
         odds_dict = odds_response.json()
 
     for competitor in competition.get("competitors", []):
-        if competitor[ID_KEY] in {"-1", "-2"}:
+        if competitor[ID_KEY] in {"-1", "-2", "0"}:
             continue
         teams.append(
             _create_espn_team(
