@@ -25,9 +25,13 @@ AMERICAN_FOOTBALL = "american-football"
 BASKETBALL = "basketball"
 FOOTBALL = "football"
 TENNIS = "tennis"
+AUSSIE_RULES = "aussie-rules"
 
 # Countries
+AUSTRALIA = "australia"
 USA = "usa"
+MEXICO = "mexico"
+BRAZIL = "brazil"
 
 # Leagues
 NCAA = "ncaa"
@@ -106,7 +110,9 @@ class OddsPortalLeagueModel(LeagueModel):
     def _paths(self) -> list[str]:
         match self.league:
             case League.AFL:
-                return ["/".join(["aussie-rules", "australia", "afl", ""])]
+                return ["/".join([AUSSIE_RULES, AUSTRALIA, "afl", ""])]
+            case League.AFLW:
+                return ["/".join([AUSSIE_RULES, AUSTRALIA, "afl-women", ""])]
             case League.ATP:
                 return [
                     "/".join([TENNIS, USA, "atp-us-open", ""]),
@@ -133,6 +139,13 @@ class OddsPortalLeagueModel(LeagueModel):
                 return ["/".join(["hockey", USA, "nhl", ""])]
             case League.WNBA:
                 return ["/".join([BASKETBALL, USA, "wnba", ""])]
+            case League.WTA:
+                return [
+                    "/".join([TENNIS, MEXICO, "wta-guadalajara", ""]),
+                    "/".join([TENNIS, MEXICO, "wta-guadalajara-doubles", ""]),
+                    "/".join([TENNIS, BRAZIL, "wta-sao-paulo-doubles", ""]),
+                    "/".join([TENNIS, BRAZIL, "wta-sao-paulo", ""]),
+                ]
             case _:
                 raise ValueError(f"Unsupported league: {self.league}")
 
